@@ -467,6 +467,10 @@ storage of variables templates")%location)
             act_section.append(service.lower())
         return act_section
 
+    def zipVars(self,*argvVarNames):
+        """Get zip() the value of the variable name"""
+        return zip(*map(self.Get,argvVarNames))
+
     def GetIniVar(self, section_dot_nameVar):
         """Получить значение переменной из конфигурационного файла
 
