@@ -185,6 +185,9 @@ class Data:
     # video verdor name
     hr_video = {'hide':True}
 
+    # videocard name
+    hr_video_name = {'hide':True}
+
     # Video driver used by xorg
     os_x11_video_drv = {'hide':True}
 
